@@ -2,19 +2,20 @@ from typing import Any, Mapping, Optional, Sequence
 
 from mkdocstrings.handlers.base import BaseHandler
 
+from . import inventory
 from .collector import CrystalCollector
 from .renderer import CrystalRenderer
 
 
 class CrystalHandler(BaseHandler):
-    pass
+    load_inventory = staticmethod(inventory.list_object_urls)
 
 
 def get_handler(
     theme: str,
     custom_templates: Optional[str] = None,
     crystal_docs_flags: Sequence[str] = (),
-    source_locations: Mapping[str, str] = (),
+    source_locations: Mapping[str, str] = {},
     **config: Any
 ) -> CrystalHandler:
     collector = CrystalCollector(
